pkg

package
v0.0.0-...-59f6aa7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// MinPhaseDuration is the minimum allowed duration for any phase
	MinPhaseDuration = 60 * time.Second
	// MaxPhaseDuration is the maximum allowed duration for any phase
	MaxPhaseDuration = 28 * 24 * time.Hour // 28 days
)

Variables

This section is empty.

Functions

func ConfigToMap

func ConfigToMap[T any](data *T) (map[string]any, error)

func Convert

func Convert(i interface{}) interface{}

func IsDatadogEnabled

func IsDatadogEnabled() bool

func IsOpenTelemetryEnabled

func IsOpenTelemetryEnabled() bool

func ParseConfig

func ParseConfig[T any](data map[string]any) (*T, error)

Types

type Duration

type Duration struct {
	time.Duration
}

func (*Duration) MarshalJSON

func (duration *Duration) MarshalJSON() ([]byte, error)

func (*Duration) UnmarshalJSON

func (duration *Duration) UnmarshalJSON(b []byte) error

Directories

Path Synopsis

Jump to