Documentation
¶
Index ¶
Constants ¶
const ( // MinPhaseDuration is the minimum allowed duration for any phase MinPhaseDuration = 60 * time.Second // MaxPhaseDuration is the maximum allowed duration for any phase MaxPhaseDuration = 28 * 24 * time.Hour // 28 days )
Variables ¶
This section is empty.
Functions ¶
func IsDatadogEnabled ¶
func IsDatadogEnabled() bool
func IsOpenTelemetryEnabled ¶
func IsOpenTelemetryEnabled() bool
Types ¶
Click to show internal directories.
Click to hide internal directories.